/* Port to bind to. */
#define XTELL_DEFAULT_PORT      4224


#define USE_READLINE
#define USE_LIBIDENT

#ifdef USE_READLINE
# include "/usr/include/readline/history.h"
# include "/usr/include/readline/readline.h"
#endif

#ifdef USE_LIBIDENT
# include "/usr/include/ident.h"
#endif


/* if your system does not have getutent & comp., comment out this */
/* BSD clones usually do not have */
#define HAVE_GETUTENT

/* define this for linux 2.2 and above (for O_NOFOLLOW flag) */
#define __USE_GNU

/* if you are compiling for Cygwin, uncomment this */
/* #define CYGWIN */

/* you probably need not touch variables below */

#define MAX_MSG_LENGTH		1024
#define MAX_LUSERNAME_LENGTH	20
#define MAX_TTY_LENGTH		8
#define MAX_HOSTNAME		255
#define MAX_SOCK_LENGTH		(MAX_MSG_LENGTH+MAX_LUSERNAME_LENGTH*2+MAX_TTY_LENGTH+5+2)
#define MAX_REPLY_LENGTH        50
#define MAX_TIME_LENGTH         20

#define TTYDIR  "/dev/"

#define VERSION "2.9"

#define LOGFILE ".xtell-log"

/* #define USE_CUSERID */

